| catdata | R Documentation |
Dummy dataset with categorical outcomes. One outcome is pain frequency at the end of the study (Visit 2). This is entered as frequency category ("PAIN_FREQUENCY") and recoded as a numeric score ("PAIN_FREQUENCY_SCORE"). All participants had pain severity of "Very Often" at baseline or Visit 1 (this data is not included). Based on pain frequency at the end of the study, participants are classified as having improved (1) or not (0) ("PAIN_IMPROVED")
catdata
A data frame with 40 rows and 8 variables:
SUBJECTNUMinteger: Unique subject ID
AGEinteger: age of participants
SEXcharacter:sex of participants
GROUPINGcharacter: Study group/arm/treatment/IP
VISITNUMBERinteger: Visit number
PAIN_FREQUENCYcharacter: pain frequency category
PAIN_FREQUENCY_SCOREinteger: pain frequency score
PAIN_IMPROVEDinteger: pain frequency improvement status
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.